==> core-components-file-upload-item-6.0.0.tgz: package/esm/Component.js <==
import React from 'react';
import cn from 'classnames';
import { Actions } from './components/actions-control/actions.js';
import { Content } from './components/content/content.js';
import { StatusControl } from './components/status-control/status-control.js';
import { FileUploadItemContext } from './context/file-upload-item-context.js';

var styles = {"component":"file-upload-item__component_kxzrk","restore":"file-upload-item__restore_kxzrk"};
require('./index.css')

var FileUploadItemComponent = function (_a) {
    var className = _a.className, children = _a.children, _b = _a.id, id = _b === void 0 ? '0' : _b, _c = _a.title, title = _c === void 0 ? '' : _c, subtitle = _a.subtitle, size = _a.size, uploadDate = _a.uploadDate, downloadLink = _a.downloadLink, download = _a.download, uploadStatus = _a.uploadStatus, error = _a.error, showDelete = _a.showDelete, showRestore = _a.showRestore, onDelete = _a.onDelete, onDownload = _a.onDownload, onRestore = _a.onRestore, disableButtons = _a.disableButtons, target = _a.target, dataTestId = _a.dataTestId, customIcon = _a.customIcon, _d = _a.iconStyle, iconStyle = _d === void 0 ? 'gray' : _d, _e = _a.progressBar, progressBar = _e === void 0 ? 0 : _e, customContent = _a.customContent, truncate = _a.truncate, imageUrl = _a.imageUrl;
    return (React.createElement("div", { className: cn(className, styles.component, uploadStatus && styles[uploadStatus.toLocaleLowerCase()]), "data-test-id": dataTestId },
        React.createElement(FileUploadItemContext.Provider
        // eslint-disable-next-line react/jsx-no-constructed-context-values
        , { 
            // eslint-disable-next-line react/jsx-no-constructed-context-values
            value: {
                showRestore: showRestore,
                uploadStatus: uploadStatus,
                error: error,
                title: title,
                subtitle: subtitle,
                uploadDate: uploadDate,
                size: size,
                id: id,
                onDownload: onDownload,
                onDelete: onDelete,
                onRestore: onRestore,
                downloadLink: downloadLink,
                download: download,
                disableButtons: disableButtons,
                target: target,
                showDelete: showDelete,
                customIcon: customIcon,
                iconStyle: iconStyle,
                progressBar: progressBar,
                customContent: customContent,
                truncate: truncate,
                imageUrl: imageUrl,
            } }, children)));
};
var FileUploadItem = Object.assign(FileUploadItemComponent, {
    StatusControl: StatusControl,
    Content: Content,
    Actions: Actions,
});

export { FileUploadItem, FileUploadItemComponent };

==> core-components-file-upload-item-6.0.1.tgz: package/esm/Component.js <==
import React from 'react';
import cn from 'classnames';
import { Actions } from './components/actions-control/actions.js';
import { Content } from './components/content/content.js';
import { StatusControl } from './components/status-control/status-control.js';
import { FileUploadItemContext } from './context/file-upload-item-context.js';

var styles = {"component":"file-upload-item__component_143gr","restore":"file-upload-item__restore_143gr"};
require('./index.css')

var FileUploadItemComponent = function (_a) {
    var className = _a.className, children = _a.children, _b = _a.id, id = _b === void 0 ? '0' : _b, _c = _a.title, title = _c === void 0 ? '' : _c, subtitle = _a.subtitle, size = _a.size, uploadDate = _a.uploadDate, downloadLink = _a.downloadLink, download = _a.download, uploadStatus = _a.uploadStatus, error = _a.error, showDelete = _a.showDelete, showRestore = _a.showRestore, onDelete = _a.onDelete, onDownload = _a.onDownload, onRestore = _a.onRestore, disableButtons = _a.disableButtons, target = _a.target, dataTestId = _a.dataTestId, customIcon = _a.customIcon, _d = _a.iconStyle, iconStyle = _d === void 0 ? 'gray' : _d, _e = _a.progressBar, progressBar = _e === void 0 ? 0 : _e, customContent = _a.customContent, truncate = _a.truncate, imageUrl = _a.imageUrl;
    return (React.createElement("div", { className: cn(className, styles.component, uploadStatus && styles[uploadStatus.toLocaleLowerCase()]), "data-test-id": dataTestId },
        React.createElement(FileUploadItemContext.Provider
        // eslint-disable-next-line react/jsx-no-constructed-context-values
        , { 
            // eslint-disable-next-line react/jsx-no-constructed-context-values
            value: {
                showRestore: showRestore,
                uploadStatus: uploadStatus,
                error: error,
                title: title,
                subtitle: subtitle,
                uploadDate: uploadDate,
                size: size,
                id: id,
                onDownload: onDownload,
                onDelete: onDelete,
                onRestore: onRestore,
                downloadLink: downloadLink,
                download: download,
                disableButtons: disableButtons,
                target: target,
                showDelete: showDelete,
                customIcon: customIcon,
                iconStyle: iconStyle,
                progressBar: progressBar,
                customContent: customContent,
                truncate: truncate,
                imageUrl: imageUrl,
            } }, children)));
};
var FileUploadItem = Object.assign(FileUploadItemComponent, {
    StatusControl: StatusControl,
    Content: Content,
    Actions: Actions,
});

export { FileUploadItem, FileUploadItemComponent };
